@@ -2,23 +2,47 @@
 
 die() { echo "$*" 1>&2 ; exit 1; }
 
+DO_XPRA=${DO_XPRA:-1}
+DO_XPRA_HTML5=${DO_XPRA_HTML5:-1}
+
+BASH="bash"
+if [ "${DEBUG:-0}" == "1" ]; then
+	BASH="bash -x"
+fi
+
 BUILDAH_DIR=`dirname $(readlink -f $0)`
 pushd ${BUILDAH_DIR}
 
-#go make a snapshot:
-pushd ../..
-rm -f dist/xpra-*.tar.xz
-python3 ./setup.py sdist --formats=xztar
-mv dist/xpra-*.tar.xz ./packaging/buildah/pkgs/
-popd
+if [ "${DO_XPRA}" == "1" ]; then
+	#go make a snapshot:
+	pushd ../..
+	rm -f pkgs/xpra-*.tar.xz
+	python3 ./setup.py sdist --formats=xztar || die "failed to create xpra source snapshot"
+	mv dist/xpra-*.tar.xz ./packaging/buildah/pkgs/
+	popd
+fi
+
+if [ "${DO_XPRA_HTML5}" == "1" ]; then
+	if [ -e "html5" ]; then
+		rm -f pkgs/xpra-html5-*.tar.xz
+		pushd html5
+		python3 ./setup.py sdist --formats=xztar || die "failed to create xpra-html5 source snapshot"
+		popd
+		cp html5/dist/xpra-html5-*.tar.xz ./pkgs/
+		cp html5/packaging/rpm/xpra-html5.spec ../rpm/
+	else
+		echo "html5 directory not found"
+		echo " skipped creating a source snapshot"
+	fi
+fi
 
 DO_DOWNLOAD="${DO_DOWNLOAD:-1}"
 if [ "${DO_DOWNLOAD}" == "1" ]; then
 	./download_source.sh
 fi
 
-RPM_DISTROS=${RPM_DISTROS:-Fedora:32 Fedora:33 Fedora:34 CentOS:8}
-DEB_DISTROS=${DEB_DISTROS:-Ubuntu:bionic Ubuntu:focal Ubuntu:groovy Ubuntu:hirsute Debian:stretch Debian:buster Debian:bullseye Debian:sid}
+RPM_DISTROS=${RPM_DISTROS:-Fedora:32 Fedora:33 Fedora:34 CentOS:7 CentOS:8}
+DEB_DISTROS=${DEB_DISTROS:-Ubuntu:bionic Ubuntu:focal Ubuntu:hirsute Debian:stretch Debian:buster Debian:bullseye Debian:sid}
 if [ -z "${DISTROS}" ]; then
 	DISTROS="$RPM_DISTROS $DEB_DISTROS"
 fi
@@ -68,7 +92,7 @@ for DISTRO in $DISTROS; do
 				--volume ${BUILDAH_DIR}/pkgs:/src/pkgs:ro,z \
 				--volume ${BUILDAH_DIR}/../rpm:/src/rpm:ro,z \
 				--volume ${BUILDAH_DIR}/../debian:/src/debian:O \
-				$TEMP_IMAGE /src/build.sh
+				$TEMP_IMAGE $BASH /src/build.sh
 	#			--volume /var/cache/dnf:/var/cache/dnf:O \
 	#buildah run \
 	#			--volume $REPO_PATH:/src/repo:noexec,nodev,z \
