@@ -94,8 +94,8 @@ def init_none():
     return Compression("none", None, None, nocompress, nodecompress)
 
 
-def init_all():
-    for x in list(ALL_COMPRESSORS)+["none"]:
+def init_compressors(*names):
+    for x in names:
         if not envbool("XPRA_%s" % (x.upper()), True):
             continue
         fn = globals().get("init_%s" % x)
@@ -107,7 +107,9 @@ def init_all():
             from xpra.log import Logger
             logger = Logger("network", "protocol")
             logger.debug("no %s", x, exc_info=True)
-init_all()
+
+def init_all():
+    init_compressors(*(list(ALL_COMPRESSORS)+["none"]))
 
 
 def use(compressor) -> bool:
@@ -142,18 +144,6 @@ def get_compressor(name):
     return c.compress
 
 
-def sanity_checks():
-    if not use("lzo") and not use("lz4"):
-        from xpra.log import Logger
-        logger = Logger("network", "protocol")
-        if not use("zlib"):
-            logger.warn("Warning: all the compressors are unavailable or disabled,")
-            logger.warn(" performance may suffer in some cases")
-        else:
-            logger.warn("Warning: zlib is the only compressor enabled")
-            logger.warn(" install and enable lz4 support for better performance")
-
-
 class Compressed:
     def __init__(self, datatype, data, can_inline=False):
         assert data is not None, "compressed data cannot be set to None"
