@@ -416,7 +416,8 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
             )
     if proxying or upgrading or upgrading_desktop:
         #when proxying or upgrading, don't exec any plain start commands:
-        opts.start = opts.start_child = []
+        opts.start = []
+        opts.start_child = []
     elif opts.exit_with_children:
         assert has_child_arg, "exit-with-children was specified but start-child* is missing!"
     elif opts.start_child:
