@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # This file is part of Xpra.
 # Copyright (C) 2010-2021 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
@@ -177,7 +177,7 @@ class SoundSource(SoundPipeline):
         self.init_file(codec)
 
 
-    def __repr__(self):
+    def __repr__(self):  #pylint: disable=arguments-differ
         return "SoundSource('%s' - %s)" % (self.pipeline_str, self.state)
 
     def cleanup(self):
