@@ -321,9 +321,11 @@ class WindowModel(BaseWindowModel):
         set_if_unset("requested-position", (ax, ay))
         set_if_unset("requested-size", (aw, ah))
         #it may have been set already:
-        v = self.get_property("set-initial-position")
-        if not v and ("position" in size_hints):
+        sip = self.get_property("set-initial-position")
+        if not sip and ("position" in size_hints):
             self._internal_set_property("set-initial-position", True)
+        elif sip is None:
+            self._internal_set_property("set-initial-position", False)
         self.update_children()
 
     def do_unmanaged(self, wm_exiting):
@@ -623,7 +625,7 @@ class WindowModel(BaseWindowModel):
         # As per ICCCM 4.1.5, even if we ignore the request
         # send back a synthetic ConfigureNotify telling the client that nothing has happened.
         with xswallow:
-            X11Window.configureAndNotify(self.xid, x, y, w, h)
+            X11Window.configureAndNotify(self.xid, x, y, w, h, event.value_mask)
         # FIXME: consider handling attempts to change stacking order here.
         # (In particular, I believe that a request to jump to the top is
         # meaningful and should perhaps even be respected.)
