@@ -32,7 +32,7 @@ RESOLUTION_ALIASES = {
     "VGA"   : (640, 480),
     "SVGA"  : (800, 600),
     "XGA"   : (1024, 768),
-    "1080p" : (1920, 1080),
+    "1080P" : (1920, 1080),
     "FHD"   : (1920, 1080),
     "4K"    : (3840, 2160),
     }
